@@ -13,7 +13,6 @@
 #include "mailtransportakonadi_debug.h"
 #include <KLocalizedString>
 
-#include <collection.h>
 #include <item.h>
 #include <itemcreatejob.h>
 #include <addressattribute.h>
@@ -34,7 +33,6 @@ public:
     Private(MessageQueueJob *qq)
         : q(qq)
     {
-        started = false;
     }
 
     MessageQueueJob *const q;
@@ -45,7 +43,7 @@ public:
     SentBehaviourAttribute sentBehaviourAttribute;
     SentActionAttribute sentActionAttribute;
     AddressAttribute addressAttribute;
-    bool started;
+    bool started = false;
 
     /**
       Returns true if this message has everything it needs and is ready to be
@@ -113,7 +111,7 @@ void MessageQueueJob::Private::outboxRequestResult(KJob *job)
         return;
     }
 
-    SpecialMailCollectionsRequestJob *requestJob
+    auto *requestJob
         = qobject_cast<SpecialMailCollectionsRequestJob *>(job);
     if (!requestJob) {
         return;
@@ -138,7 +136,7 @@ void MessageQueueJob::Private::outboxRequestResult(KJob *job)
     // Store the item in the outbox.
     const Collection collection = requestJob->collection();
     Q_ASSERT(collection.isValid());
-    ItemCreateJob *cjob = new ItemCreateJob(item, collection);   // job autostarts
+    auto *cjob = new ItemCreateJob(item, collection);   // job autostarts
     q->addSubjob(cjob);
 }
 
@@ -190,7 +188,7 @@ void MessageQueueJob::setMessage(const Message::Ptr &message)
 
 void MessageQueueJob::start()
 {
-    SpecialMailCollectionsRequestJob *rjob = new SpecialMailCollectionsRequestJob(this);
+    auto *rjob = new SpecialMailCollectionsRequestJob(this);
     rjob->requestDefaultCollection(SpecialMailCollections::Outbox);
     connect(rjob, &SpecialMailCollectionsRequestJob::result, this, [this](KJob *job) {
         d->outboxRequestResult(job);
